package app.insti.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

import app.insti.R;
import app.insti.api.model.SubActivity;

public class SubActivitiesAdapter extends RecyclerView.Adapter<SubActivitiesAdapter.SubActivitiesViewHolder>{

    private List<SubActivity> subActivityList = new ArrayList<>();
    private OnSubActivityListener onSubActivityListener;


    public SubActivitiesAdapter(List<SubActivity> subActivityList,OnSubActivityListener onSubActivityListener){
        this.subActivityList = subActivityList;
        this.onSubActivityListener = onSubActivityListener;
    }

    @NonNull
    @Override
    public SubActivitiesViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater inflater = LayoutInflater.from(parent.getContext());
        View view = inflater.inflate(R.layout.resource_layout_sub_activities,parent,false);
        return new SubActivitiesViewHolder(view,onSubActivityListener);
    }

    @Override
    public void onBindViewHolder(@NonNull SubActivitiesViewHolder holder, int position) {
        SubActivity subActivity = subActivityList.get(position);
        holder.txtViewSubActivityName.setText(subActivity.getSubActivityName());
        holder.txtViewSubActivityShortDescription.setText(subActivity.getSubActivityShortDescription());
        Picasso.get().load(subActivity.getAvatarUrl()).fit().centerCrop().into(holder.imgViewSubActivity);
    }

    @Override
    public int getItemCount() {
        return subActivityList.size();
    }

    public class SubActivitiesViewHolder extends RecyclerView.ViewHolder implements View.OnClickListener {
        ImageView imgViewSubActivity;
        TextView txtViewSubActivityName;
        TextView txtViewSubActivityShortDescription;
        LinearLayout linearLayoutSubActivity;
        OnSubActivityListener onSubActivityListener;

        public SubActivitiesViewHolder(@NonNull View itemView, OnSubActivityListener onSubActivityListener) {
            super(itemView);
            imgViewSubActivity = itemView.findViewById(R.id.imgViewSubActivity);
            txtViewSubActivityName = itemView.findViewById(R.id.txtViewSubActivityName);
            txtViewSubActivityShortDescription = itemView.findViewById(R.id.txtViewSubActivityShortDescription);
            linearLayoutSubActivity = itemView.findViewById(R.id.linearLayoutSubActivity);
            this.onSubActivityListener = onSubActivityListener;
            itemView.setOnClickListener(this);
        }

        @Override
        public void onClick(View v) {
            onSubActivityListener.onSubActivityClick(getAdapterPosition());
        }
    }

    public interface OnSubActivityListener{
        void onSubActivityClick(int position);
    }
}